@@ -2,9 +2,21 @@ use strict;
 use warnings;
 
 package WebService::Shippo;
+our $VERSION = '0.0.21';
 # ABSTRACT: A Shippo Perl API wrapper
-our $VERSION = '0.0.20';
-require WebService::Shippo::Entities;
+
+require WebService::Shippo::Addresses;
+require WebService::Shippo::CarrierAccounts;
+require WebService::Shippo::CustomsDeclarations;
+require WebService::Shippo::CustomsItems;
+require WebService::Shippo::Manifests;
+require WebService::Shippo::Parcels;
+require WebService::Shippo::Rates;
+require WebService::Shippo::Refunds;
+require WebService::Shippo::Shipments;
+require WebService::Shippo::Transactions;
+require WebService::Shippo::Config;
+
 use boolean ':all';
 use Params::Callbacks ( 'callbacks', 'callback' );
 use base ( 'Exporter' );
@@ -36,7 +48,7 @@ BEGIN {
 }
 
 1;
-
+__END__
 =pod
 
 =encoding utf8
@@ -52,7 +64,7 @@ WebService::Shippo - Shippo API Client
 
 =head1 VERSION
 
-version 0.0.20
+version 0.0.21
 
 =head1 SYNOPIS
 
