@@ -4,7 +4,7 @@ use MRO::Compat 'c3';
 
 package WebService::Shippo::CustomsDeclaration;
 use base qw(
-    WebService::Shippo::Resource
+    WebService::Shippo::Item
     WebService::Shippo::Create
     WebService::Shippo::Fetch
 );
@@ -32,7 +32,7 @@ WebService::Shippo::CustomsDeclaration - Customs Declaration class
 
 =head1 VERSION
 
-version 0.0.20
+version 0.0.21
 
 =head1 DESCRIPTION
 
