@@ -5,7 +5,7 @@ use MRO::Compat 'c3';
 package WebService::Shippo::Rate;
 require WebService::Shippo::Shipment;
 use base qw(
-    WebService::Shippo::Resource
+    WebService::Shippo::Item
     WebService::Shippo::Fetch
 );
 
@@ -38,7 +38,7 @@ WebService::Shippo::Rate - Rate class
 
 =head1 VERSION
 
-version 0.0.20
+version 0.0.21
 
 =head1 DESCRIPTION
 
