@@ -4,7 +4,7 @@ use MRO::Compat 'c3';
 
 package WebService::Shippo::Refund;
 use base qw(
-    WebService::Shippo::Resource
+    WebService::Shippo::Item
     WebService::Shippo::Create
     WebService::Shippo::Fetch
     WebService::Shippo::Async
@@ -33,7 +33,7 @@ WebService::Shippo::CarrierAccount - Refund class
 
 =head1 VERSION
 
-version 0.0.20
+version 0.0.21
 
 =head1 DESCRIPTION
 
