@@ -8,7 +8,7 @@ use Carp              ( 'confess' );
 use Params::Callbacks ( 'callbacks', 'callback' );
 use Scalar::Util      ( 'blessed' );
 use base qw(
-    WebService::Shippo::Resource
+    WebService::Shippo::Item
     WebService::Shippo::Create
     WebService::Shippo::Fetch
     WebService::Shippo::Currency
@@ -80,7 +80,7 @@ WebService::Shippo::Shipment - Shipment class
 
 =head1 VERSION
 
-version 0.0.20
+version 0.0.21
 
 =head1 DESCRIPTION
 
