@@ -6,7 +6,7 @@ package WebService::Shippo::Transaction;
 use Carp         ( 'confess' );
 use Scalar::Util ( 'blessed' );
 use base qw(
-    WebService::Shippo::Resource
+    WebService::Shippo::Item
     WebService::Shippo::Create
     WebService::Shippo::Fetch
     WebService::Shippo::Async
@@ -52,7 +52,7 @@ WebService::Shippo::Transaction - Transaction class
 
 =head1 VERSION
 
-version 0.0.20
+version 0.0.21
 
 =head1 DESCRIPTION
 
